## Documentation Structure

This directory contains the following documentation:

- [Provider Architecture](provider_architecture.md): Overview of the MCP Tool Provider architecture
- [System Lifecycles](system-lifecycles.md): Detailed lifecycle diagrams and state transitions